==> oddmuse-1.310.tar.gz: oddmuse-1.310/german-utf8.pl <==
# UTF-8 encoded German translation file for use with Oddmuse
#
# Copyright (c) 2003  Karl Loncarek <karl@loncarek.de>
# Copyright (c) 2003, 2004  Alex Schröder <alex@oddmuse.org>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
# Diese Datei sollte im gleichen Verzeichnis wie die
# Konfigurationsdatei gespeichert werden.  In der Konfigurationsdatei
# muss diese Datei dann geladen werden:
#
# do 'german-utf8.pl';
#
# Diese Übersetzung wurde für Oddmuse 1.301 erstellt.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Lesen nicht erlaubt: Benutzer, IP oder Netzwerk ist gesperrt.
Could not create %s
Konnte %s nicht erzeugen
Invalid UserName %s: not saved.
Ungültiger Benutzername %s: nicht gespeichert.
UserName must be 50 characters or less: not saved
Länge des Benutzernamens maximal 50 Zeichen: nicht gespeichert.
XML::RSS is not available on this system.
Das XML::RSS Modul ist auf diesem System nicht installiert.
LWP::UserAgent is not available on this system.
Das LWP::UserAgent Modul ist auf diesem System nicht installiert.
diff
Unterschiede
history
alte Versionen
 . . . . 
 . . . . 
Click to create this page
Hier klicken um die Seite zu erstellen
http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
http://www.kelkoo.de/shopbot/search.jsp?from=shopbot&catPath=de%2Fbook&catId=100801&title=&author=&isbn=%s&maxprice=&x=36&y=9
http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.de/exec/obidos/ISBN=%s
alternate
Alternativ
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
Suchen
Invalid action parameter %s
Ungültiger action Parameter: %s
Invalid URL.
Ungültige URL.
Page name is too long: %s
Seitenname zu lang: %s
Invalid Page %s
Ungültige Seite %s
Invalid Page %s (must not end with .db)
Ungültige Seite %s (Darf nicht mit .db enden)
Invalid Page %s (must not end with .lck)
Ungültige Seite %s (Darf nicht mit .lck enden)
Page name may not contain space characters: %s
Seitenname darf keine Leerzeichen enthalten: %s
Preview:
Vorschau:
Preview only, not yet saved
Vorschau, noch nicht gespeichert
Please go on to %s.
Bitte machen Sie weiter bei %s.
Could not open %s log file
Kann Logdatei %s nicht öffnen
Error was
Fehler war
Note: This error is normal if no changes have been made.
HINWEIS: Dieser Fehler ist normal, wenn keine Änderungen durchgeführt wurden.
Could not open old %s log file
Konnte alte Logdatei %s nicht öffnen
No updates since %s
Keine Änderungen seit %s
Updates since %s
Änderungen seit %s
Updates in the last %s days
Änderungen der letzten %s Tage
Updates in the last %s day
Änderungen der letzten %s Tage
for %s only
nur für %s
List latest change per page only
Nur letzte Änderungen pro Seite
List only major changes
Nur grössere Änderungen
Include minor changes
Inklusive kleinere Änderungen
List all changes
Alle Änderungen
%s days
%s Tage
List later changes
Spätere Änderungen
Username:
Benutzername:
Host:
Rechner:
Language:
Sprache:
Filters
Filter
Go!
Los!
(minor)
(Klein)
rollback
bis hier alles Rückgängig machen
from %s
von %s
History of %s
Historie von %s
Compare
Vergleichen
Revision %s
Version %s
by
von
Rolling back changes
Änderungen werden rückgängig gemacht
Missing target for rollback.
Das Stichdatum fehlt.
Target for rollback is too far back.
Das Stichdatum liegt zu weit zurück.
Rollback to %s
Rückgängig gemacht auf den Stand vom %s
%s rolled back
Änderungen für %s rückgängig gemacht
[Home]
[Erste Seite]
redirected from %s
Umgeleitet von %s
Click to search for references to this page
Klicken um nach Verweisen auf diese Seite zu suchen
Cookie: 
Cookie: 
new comment
Neuer Kommentar
Save
Speichern
Preview
Vorschau
Comments on this page
Kommentare zu dieser Seite
Edit revision %s of this page
Version %s dieser Seite bearbeiten
Edit text of this page
Text dieser Seite bearbeiten
This page is read-only
Diese Seite ist schreibgeschützt
View other revisions
Andere Versionen ansehen
View current revision
Aktuelle Version ansehen
View all changes
Alle Änderungen ansehen
Back to %s
Zurück zu %s
Last edited
Zuletzt geändert
Edited
Geändert
by %s
von %s
(diff)
(Unterschiede)
Warning
Warnung
Database is stored in temporary directory %s
Datenbank wird im temporären Verzeichnis %s gespeichert
%s seconds
%s Sekunden
The same page on other sites:
Dieselbe Seite auf anderen Sites:
EditNearLinks
Diese Seiten lokal erstellen
Search:
Suchen:
Replace:
Ersetzen mit:
Validate HTML
HTML überprüfen
Validate CSS
CSS überprüfen
Difference (from revision %1 to %2)
Unterschiede (zwischen Version %1 und %2)
revision %s
Version %s
current revision
Aktuelle Version
Difference (from prior %s revision)
(%s Änderungen)
major
größere
minor
kleinere
No diff available.
Keine Unterschiede vorhanden.
Changed:
Geändert:
Removed:
Gelöscht:
Added:
Eingefügt:
to
stattdessen:
Revision %s not available
Version %s nicht verfügbar
showing current revision instead
Stattdessen Anzeige der aktuellen Version
Showing revision %s
Anzeige Version %s
Cannot save an nameless page.
Eine Seite ohne Namen kann nicht gespeichert werden.
Cannot open %s
%s kann nicht geöffnet werden
Cannot write %s
%s kann nicht geschrieben werden
Could not get %s lock
Die %s Sperre konnte nicht gesetzt werden.
Unlocking
Aufheben der Sperren
This operation may take several seconds...
Das könnte einige Sekunden dauern...
Forced unlock of %s lock.
Erzwungene Aufhebung der Sperre von %s.
No unlock required.
Aufhebung der Sperre nicht notwendig.
%s hours ago
%s Stunden vorher
1 hour ago
Eine Stunde vorher
%s minutes ago
%s Minuten vorher
1 minute ago
Eine Minute vorher
%s seconds ago
%s Sekunden vorher
1 second ago
Eine Sekunde vorher
just now
Genau jetzt
Editing Denied
Bearbeitung verweigert
Editing not allowed: user, ip, or network is blocked.
Bearbeitung nicht erlaubt: Benutzer, IP oder Netzwerk ist gesperrt.
Contact the wiki administrator for more information.
Für weitere Informationen setzen Sie sich mit dem WIKI Administrator in Verbindung.
The rule %s matched for you.
Die Regel %s hat angesprochen.
See %s for more information.
Siehe %s für weitere Informationen.
Editing not allowed: %s is read-only.
Bearbeitung nicht erlaubt: %s ist schreibgeschützt.
Only administrators can upload files.
Nur Administratoren dürfen Dateien hochladen.
Editing revision %s of
Bearbeitung Version %s von
Editing %s
Bearbeitung %s
Editing old revision %s.
Bearbeitung alte Version %s.
Saving this page will replace the latest revision with this text.
Das Speichern dieser Seite wird die letzte Version durch diesen Text ersetzen.
Summary:
Zusammenfassung:
This change is a minor edit.
Dies ist eine kleinere Änderung.
Replace this file with text.
Ersetze diese Datei mit Text.
Replace this text with a file.
Ersetze diesen Text mit einer Datei.
File to upload: 
Hochzuladende Datei: 
Files of type %s are not allowed.
Der Dateityp %s ist nicht erlaubt.
Password
Passwort
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ihr Passwort wird in einem Cookie gespeichert, falls Sie Cookies eingeschaltet haben. Cookies können verloren gehen, wenn Sie die Verbindung von einer anderen Maschine, von einem anderen Account oder mit anderer Software herstellen.
You are currently an administrator on this site.
Sie sind momentan ein Administrator auf dieser Webseite.
You are currently an editor on this site.
Sie sind momentan ein Bearbeiter auf dieser Webseite.
You are a normal user on this site.
Sie sind ein normaler Benutzer auf dieser Webseite.
Your password does not match any of the  administrator or editor passwords.
Ihr Passwort stimmt nicht mit einem Administrator- oder Bearbeiter-Passwort überein.
Password:
Passwort:
This site does not use admin or editor passwords.
Diese Webseite verwendet keine Administrator- oder Bearbeiter-Passwörter.
This operation is restricted to site editors only...
Diese Aktion darf nur von Bearbeitern durchgeführt werden...
This operation is restricted to administrators only...
Diese Aktion darf nur von Administratoren durchgeführt werden...
Index of all pages
Index aller Seiten
all pages
alle Seiten
permanent anchors
permanente Anker
near links
"nahe" Seiten
(for %s)
(für %s)
%s pages found.
%s Seiten gefunden.
Replaced: %s
Ersetzt: %s
Search for: %s
Suche nach: %s
View changes for these pages
Änderungen für diese Seiten
Search sites on the %s as well
Sites auf der %s auch durchsuchen
and
und
or
oder
Fetching results from %s:
Resultate von %s:
Near pages:
Nahe Seiten:
last updated
Zuletzt geändert
Full Link List
Volle Link-Liste
Complete Content
Vollständiger Inhalt
The main page is %s.
Die Hauptseite ist %s.
Editing not allowed for %s.
Das bearbeiten von %s ist nicht erlaubt.
SampleUndefinedPage
BeispielEinerUndefiniertenSeite
%s cannot be defined.
%s kann nicht definiert werden.
Sample_Undefined_Page
Beispiel_Einer_Undefinierten_Seite
[[%s]] cannot be defined.
[[%s]] kann nicht definiert werden.
Only an administrator can create %s
Nur ein Administrator kann %s erstellen
Transfer Error: %s
Transferfehler: %s
Browser reports no file info.
Der Browser hat keine Dateiinformationen geliefert.
Browser reports no file type.
Der Browser hat keinen Dateityp geliefert.
This page was changed by somebody else %s.
Diese Seite wurde von einer anderen Person %s verändert
The changes conflict.  Please check the page again.
Die Änderungen beeinträchtigen sich gegenseitig.  Bitte überprüfen Sie die Seite nochmals.
Please check whether you overwrote those changes.
Bitte überprüfen Sie, ob diese Änderungen überschrieben worden sind.
Anonymous
Unbekannt
Could not get a lock to merge!
Sperre zum automatischen Abgleichen zweier Versionen konnte nicht reserviert werden!
you
Sie
ancestor
Vorgänger
other
Andere Person
Ping
Ping
No response.
Keine Antwort.
Maintenance on all pages
Wartungsarbeiten auf allen Seiten
Maintenance not done.
Wartungsarbeiten nicht erfolgt.
(Maintenance can only be done once every 12 hours.)
(Wartungsarbeiten können frühestens alle 12 Stunden durchgeführt werden.)
Remove the "maintain" file or wait.
Löschen Sie die Datei "maintain" oder warten Sie.
Main lock obtained.
Hauptsperre aktiviert.
Expiring keep files and deleting pages marked for deletion
Alte Versionen werden aus dem Archiv entfernt und Seiten, die als gelöscht markiert wurden, werden gelöscht
deleted
Datei gelöscht
Moving part of the %s log file.
Verschiebe einen Teil der Logdatei %s.
Moving %s log entries.
Verschiebe %s Log-Einträge.
Getting page index file for %s.
Hole den Seitenindex für %s.
Main lock released.
Hauptsperre aufgehoben.
Set or Remove global edit lock
Erzeugen oder Aufheben der globalen Bearbeitungssperre
Edit lock created.
Bearbeitungssperre erzeugt.
Edit lock removed.
Bearbeitungssperre aufgehoben.
Set or Remove page edit lock
Erzeugen oder aufheben der Seiten-Bearbeitungssperre
Missing page id to lock/unlock...
Fehlende Seiten-ID für die Erzeugung/Aufhebung der Sperre...
Lock for %s created.
Sperre von %s erzeugt.
Lock for %s removed.
Sperre von %s aufheben.
Displaying Wiki Version
Anzeige der Wiki Version
Inter links:
Inter Links:
Near links:
Nahe Links:
Too many connections by %s
Zu viele Verbindungen durch %s
Recent Visitors
Kürzliche Besucher
Referrers
Links auf diese Seite
All Referrers
Alle Links auf diesen Wiki
anchor first defined here: %s
Der Anker wurde hier zuerst definiert: %s
Click to search for references to this permanent anchor
Klicken um nach Verweisen auf diesen permanenten Anker zu suchen
END_OF_TRANSLATION

==> oddmuse-1.437.tar.gz: oddmuse-1.437/german-utf8.pl <==
# UTF-8 encoded German translation file for use with Oddmuse
#
# Copyright (c) 2003  Karl Loncarek <karl@loncarek.de>
# Copyright (c) 2003, 2004  Alex Schröder <alex@emacswiki.org>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Lesen nicht erlaubt: Benutzer, IP oder Netzwerk ist gesperrt.
Could not create %s
Konnte %s nicht erzeugen
Invalid UserName %s: not saved.
Ungültiger Benutzername %s: nicht gespeichert.
UserName must be 50 characters or less: not saved
Länge des Benutzernamens maximal 50 Zeichen: nicht gespeichert.
XML::RSS is not available on this system.
Das XML::RSS Modul ist auf diesem System nicht installiert.
diff
Unterschiede
history
alte Versionen
%s returned no data, or LWP::UserAgent is not available.
Entweder liefert %s liefert keine Daten, oder das LWP::UserAgent Modul ist auf diesem System nicht installiert.
RSS parsing failed for %s
Die RSS Daten von %s sind ungültig; sie können nicht verarbeitet werden
 . . . . 
 . . . . 
Click to create this page
Hier klicken um die Seite zu erstellen
http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
http://www.kelkoo.de/shopbot/search.jsp?from=shopbot&catPath=de%2Fbook&catId=100801&title=&author=&isbn=%s&maxprice=&x=36&y=9
http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.de/exec/obidos/ISBN=%s
alternate
Alternativ
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
http://de.bookbutler.info/vergleich/%s
search
Suchen
Invalid action parameter %s
Ungültiger action Parameter: %s
Invalid URL.
Ungültige URL.
Page name is missing
Seitenname fehlt
Page name is too long: %s
Seitenname zu lang: %s
Invalid Page %s
Ungültige Seite %s
Invalid Page %s (must not end with .db)
Ungültige Seite %s (Darf nicht mit .db enden)
Invalid Page %s (must not end with .lck)
Ungültige Seite %s (Darf nicht mit .lck enden)
Page name may not contain space characters: %s
Seitenname darf keine Leerzeichen enthalten: %s
Preview:
Vorschau:
Preview only, not yet saved
Vorschau, noch nicht gespeichert
Please go on to %s.
Bitte machen Sie weiter bei %s.
Could not open %s log file
Kann Logdatei %s nicht öffnen
Error was
Fehler war
Note: This error is normal if no changes have been made.
HINWEIS: Dieser Fehler ist normal, wenn keine Änderungen durchgeführt wurden.
Could not open old %s log file
Konnte alte Logdatei %s nicht öffnen
No updates since %s
Keine Änderungen seit %s
Updates since %s
Änderungen seit %s
Updates in the last %s days
Änderungen der letzten %s Tage
Updates in the last %s day
Änderungen der letzten %s Tage
for %s only
nur für %s
List latest change per page only
Nur letzte Änderungen pro Seite
List all changes
Alle Änderungen
List only major changes
Nur grössere Änderungen
Include minor changes
Inklusive kleinere Änderungen
%s days
%s Tage
List later changes
Spätere Änderungen
Username:
Benutzername:
Host:
Rechner:
Language:
Sprache:
Filters
Filter
Go!
Los!
(minor)
(Klein)
rollback
bis hier alles Rückgängig machen
new
Neue Seite
from %s
von %s
History of %s
Andere Versionen von %s
Compare
Vergleichen
Revision %s
Version %s
by
von
Rolling back changes
Änderungen werden rückgängig gemacht
Missing target for rollback.
Das Stichdatum fehlt.
Target for rollback is too far back.
Das Stichdatum liegt zu weit zurück.
Rollback to %s
Rückgängig gemacht auf den Stand vom %s
%s rolled back
Änderungen für %s rückgängig gemacht
[Home]
[Erste Seite]
redirected from %s
Umgeleitet von %s
Click to search for references to this page
Klicken um nach Verweisen auf diese Seite zu suchen
Cookie: 
Cookie: 
Warning
Warnung
Database is stored in temporary directory %s
Datenbank wird im temporären Verzeichnis %s gespeichert
%s seconds
%s Sekunden
The same page on other sites:
Dieselbe Seite auf anderen Sites:
EditNearLinks
Diese Seiten lokal erstellen
Last edited
Zuletzt geändert
Edited
Geändert
by %s
von %s
(diff)
(Unterschiede)
Run maintenance
Wartungsarbeiten durchführen
Unlock site
Wiki entsperren
Lock site
Wiki sperren
Unlock page
Seite entsperren
Lock page
Seite sperren
Comments on this page
Kommentare zu dieser Seite
Edit revision %s of this page
Version %s dieser Seite bearbeiten
Edit text of this page
Diese Seite bearbeiten
e
b
This page is read-only
Diese Seite ist schreibgeschützt
View other revisions
Andere Versionen dieser Seite
View current revision
Zurück zur aktuellen Version
View all changes
Liste aller Änderungen, auch ohne vorhandener Version
Back to %s
Zurück zu %s
new comment
Neuer Kommentar
s
s
Save
Speichern
Preview
Vorschau
Search:
Suchen:
Replace:
Ersetzen mit:
Validate HTML
HTML überprüfen
Validate CSS
CSS überprüfen
Difference (from revision %1 to %2)
Unterschiede (zwischen Version %1 und %2)
revision %s
Version %s
current revision
Aktuelle Version
Difference (from prior %s revision)
(%s Änderungen)
major
größere
minor
kleinere
No diff available.
Keine Unterschiede vorhanden.
Changed:
Geändert:
Removed:
Gelöscht:
Added:
Eingefügt:
to
stattdessen:
Revision %s not available
Version %s nicht verfügbar
showing current revision instead
Stattdessen Anzeige der aktuellen Version
Showing revision %s
Anzeige der alten Version %s
Cannot save an nameless page.
Eine Seite ohne Namen kann nicht gespeichert werden.
Cannot open %s
%s kann nicht geöffnet werden
Cannot write %s
%s kann nicht geschrieben werden
Could not get %s lock
Die %s Sperre konnte nicht gesetzt werden.
Unlocking
Aufheben der Sperren
This operation may take several seconds...
Das könnte einige Sekunden dauern...
Forced unlock of %s lock.
Erzwungene Aufhebung der Sperre von %s.
No unlock required.
Aufhebung der Sperre nicht notwendig.
%s hours ago
%s Stunden vorher
1 hour ago
eine Stunde vorher
%s minutes ago
%s Minuten vorher
1 minute ago
eine Minute vorher
%s seconds ago
%s Sekunden vorher
1 second ago
eine Sekunde vorher
just now
genau jetzt
Editing Denied
Bearbeitung verweigert
Editing not allowed: user, ip, or network is blocked.
Bearbeitung nicht erlaubt: Benutzer, IP oder Netzwerk ist gesperrt.
Contact the wiki administrator for more information.
Für weitere Informationen setzen Sie sich mit dem Wiki Administrator in Verbindung.
The rule %s matched for you.
Die Regel %s hat angesprochen.
See %s for more information.
Siehe %s für weitere Informationen.
Editing not allowed: %s is read-only.
Bearbeitung nicht erlaubt: %s ist schreibgeschützt.
Only administrators can upload files.
Nur Administratoren dürfen Dateien hochladen.
Editing revision %s of
Bearbeiten der Version %s von
Editing %s
Bearbeiten von %s
Editing old revision %s.
Hiermit wird die alte Version %s bearbeitet.
Saving this page will replace the latest revision with this text.
Wird diese Änderung gespeichert, wird dies die aktuelle Version ersetzen. Damit werden die später gemachten Änderungen verloren gehen.
Summary:
Zusammenfassung:
This change is a minor edit.
Dies ist eine kleinere Änderung.
Replace this file with text.
Diese Datei durch Text ersetzen.
Replace this text with a file.
Datei hochladen und den Text durch diese Datei ersetzen.
File to upload: 
Hochzuladende Datei: 
Files of type %s are not allowed.
Der Dateityp %s ist nicht erlaubt.
Password
Passwort
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ihr Passwort wird in einem Cookie gespeichert, falls Sie Cookies eingeschaltet haben. Cookies können verloren gehen, wenn Sie die Verbindung von einer anderen Maschine, von einem anderen Account oder mit anderer Software herstellen.
You are currently an administrator on this site.
Sie sind momentan ein Administrator auf dieser Webseite.
You are currently an editor on this site.
Sie sind momentan ein Bearbeiter auf dieser Webseite.
You are a normal user on this site.
Sie sind ein normaler Benutzer auf dieser Webseite.
Your password does not match any of the  administrator or editor passwords.
Ihr Passwort stimmt nicht mit einem Administrator- oder Bearbeiter-Passwort überein.
Password:
Passwort:
This site does not use admin or editor passwords.
Diese Webseite verwendet keine Administrator- oder Bearbeiter-Passwörter.
This operation is restricted to site editors only...
Diese Aktion darf nur von Bearbeitern durchgeführt werden...
This operation is restricted to administrators only...
Diese Aktion darf nur von Administratoren durchgeführt werden...
Index of all pages
Index aller Seiten
all pages
alle Seiten
permanent anchors
permanente Anker
near links
"nahe" Seiten
(for %s)
(für %s)
%s pages found.
%s Seiten gefunden.
Replaced: %s
Ersetzt: %s
Search for: %s
Suche nach: %s
View changes for these pages
Änderungen für diese Seiten
Search sites on the %s as well
Sites auf der %s auch durchsuchen
and
und
or
oder
Fetching results from %s:
Resultate von %s:
Near pages:
Nahe Seiten:
last updated
Zuletzt geändert
Complete Content
Vollständiger Inhalt
The main page is %s.
Die Hauptseite ist %s.
Editing not allowed for %s.
Das bearbeiten von %s ist nicht erlaubt.
SampleUndefinedPage
BeispielEinerUndefiniertenSeite
%s cannot be defined.
%s kann nicht definiert werden.
Sample_Undefined_Page
Beispiel_Einer_Undefinierten_Seite
[[%s]] cannot be defined.
[[%s]] kann nicht definiert werden.
Only an administrator can create %s.
Nur ein Administrator can %s erstellen.
Transfer Error: %s
Transferfehler: %s
Browser reports no file info.
Der Browser hat keine Dateiinformationen geliefert.
Browser reports no file type.
Der Browser hat keinen Dateityp geliefert.
Edit Denied
Bearbeiten verboten
The page contains banned text.
Diese Seite enthält verbotenen Text.
This page was changed by somebody else %s.
Diese Seite wurde von einer anderen Person %s verändert
The changes conflict.  Please check the page again.
Die Änderungen beeinträchtigen sich gegenseitig.  Bitte überprüfen Sie die Seite nochmals.
Please check whether you overwrote those changes.
Bitte überprüfen Sie, ob diese Änderungen überschrieben worden sind.
Anonymous
Unbekannt
Could not get a lock to merge!
Sperre zum automatischen Abgleichen zweier Versionen konnte nicht reserviert werden!
you
Sie
ancestor
Vorgänger
other
Andere Person
Maintenance on all pages
Wartungsarbeiten auf allen Seiten
Maintenance not done.
Wartungsarbeiten nicht erfolgt.
(Maintenance can only be done once every 12 hours.)
(Wartungsarbeiten können frühestens alle 12 Stunden durchgeführt werden.)
Remove the "maintain" file or wait.
Löschen Sie die Datei "maintain" oder warten Sie.
Main lock obtained.
Hauptsperre aktiviert.
Expiring keep files and deleting pages marked for deletion
Alte Versionen werden aus dem Archiv entfernt und Seiten, die als gelöscht markiert wurden, werden gelöscht
not deleted: 
konnte nicht gelöscht werden: 
deleted
Datei gelöscht
Moving part of the %s log file.
Verschiebe einen Teil der Logdatei %s.
Moving %s log entries.
Verschiebe %s Log-Einträge.
Getting page index file for %s.
Hole den Seitenindex für %s.
Main lock released.
Hauptsperre aufgehoben.
Set or Remove global edit lock
Erzeugen oder Aufheben der globalen Bearbeitungssperre
Edit lock created.
Bearbeitungssperre erzeugt.
Edit lock removed.
Bearbeitungssperre aufgehoben.
Set or Remove page edit lock
Erzeugen oder aufheben der Seiten-Bearbeitungssperre
Missing page id to lock/unlock...
Fehlende Seiten-ID für die Erzeugung/Aufhebung der Sperre...
Lock for %s created.
Sperre von %s erzeugt.
Lock for %s removed.
Sperre von %s aufheben.
Displaying Wiki Version
Anzeige der Wiki Version
Inter links:
Inter Links:
Near links:
Nahe Links:
Too many connections by %s
Zu viele Verbindungen durch %s
Please do not fetch more than %1 pages in %2 seconds.
Bitte rufen sie nicht mehr als %1 Seiten in %2 Sekunden auf.
Recent Visitors
Kürzliche Besucher
Referrers
Links auf diese Seite
All Referrers
Alle Links auf diesen Wiki
anchor first defined here: %s
Der Anker wurde hier zuerst definiert: %s
Click to search for references to this permanent anchor
Klicken um nach Verweisen auf diesen permanenten Anker zu suchen
the page %s also exists
die Seite %s existiert ebenfalls
Deleting %s
%s löschen
Deleted %s
%s wurde gelöscht
Renaming %1 to %2.
Die %1 Seite wird zu %2 umbenannt
The page %s does not exist
Die %s Seite gibt es nicht
The page %s already exists
Die %s Seite gibt es schon
Renamed to %s
Wurde auf %s umbenannt
Renamed from %s
Ehemals %s
Renamed %1 to %2.
Die %1 Seite wurde zu %2 umbenannt
Delete page
Seite löschen
Rename this page to:
Bennen diese Seite um:
Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
Um einen Kalender zu produzieren fehlt entweder cal(1), Date::Calc(3) oder Date::Pcalc(3).
The match parameter is missing.
Der 'match' Parameter fehlt noch.
Page Collection for %s
Seitensammlung für %s
Calendar %s
Kalender %s
Footnotes:
Fussnoten:
image: %s
Bild: %s
Languages:
Sprachen:
Show!
Zeigen!
Define
Definieren
Full Link List
Liste aller Verweise
Clearing Cache
Cache wird geleert
Done.
Fertig.
Generating Link Database
Verweis Datenbank wird angelegt
The 404 handler extension requires the link data extension (links.pl).
Die 404 handler Erweiterung benötigt die Link Data Erweiterung (links.pl).
Orphan List
Liste der Waisen
Trail: 
Weg: 
None
Keiner
Type
Typ
Portrait
Portrait
Thread: %s
Thread: %s
ID parameter is missing.
ID Parameter fehlt noch.
Thread %s does not exist.
Den %s Thread gibt es nicht.
Page %s does not contain a thread.
Die %s Seite enthält keinen Thread.
Add
Hinzufügen
URL parameter is missing.
URL Parameter fehlt noch.
Add to %s thread
Zum %s Thread hinzufügen
Below:
Darunter:
URL:
URL:
Name:
Name:
Blog
Blog
END_OF_TRANSLATION
